# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that defines the behavior of the "About"
menu item in the popup menu.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gtk import ImageMenuItem

class AboutMenuItem(ImageMenuItem):
	"""
	This class defines the behavior of the "About" menu item.
	"""

	def __init__(self, player):
		"""
		Initialize object.

		@param self: Reference to the AboutMenuItem instance.
		@type self: A AboutMenuItem object.

		@param player: Reference to the Player Instance.
		@type player: A Player object.
		"""
		from gtk import STOCK_ABOUT
		ImageMenuItem.__init__(self, STOCK_ABOUT)
		self.__init_attributes(player)
		self.connect("activate", self.__activate_cb)

	def __init_attributes(self, player):
		"""
		Initialize data attributes.

		@param self: Reference to the AboutMenuItem instance.
		@type self: A AboutMenuItem object.

		@param player: Reference to the Player Instance.
		@type player: A Player object.
		"""
		self.__player = player
		return

	def __activate_cb(self, *args):
		"""
		Handles callback when the "activate" signal is emitted.

		@param self: Reference to the AboutMenuItem instance.
		@type self: A AboutMenuItem object.
		"""
		self.__player.trigger("show_about_dialog")
		return True
